=== modified file 'bzrlib/revision.py'
--- bzrlib/revision.py	2009-04-04 02:50:01 +0000
+++ bzrlib/revision.py	2009-04-06 21:01:10 +0000
@@ -56,6 +56,7 @@
         self.revision_id = revision_id
         self.properties = properties or {}
         self._check_properties()
+        self.committer = None
         self.parent_ids = []
         self.parent_sha1s = []
         """Not used anymore - legacy from for 4."""
@@ -122,7 +123,11 @@
         If the revision properties contain any author names,
         return the first. Otherwise return the committer name.
         """
-        return self.get_apparent_authors()[0]
+        authors = self.get_apparent_authors()
+        if authors:
+            return authors[0]
+        else:
+            return None
 
     def get_apparent_authors(self):
         """Return the apparent authors of this revision.
@@ -134,9 +139,9 @@
         """
         authors = self.properties.get('authors', None)
         if authors is None:
-            author = self.properties.get('author', None)
+            author = self.properties.get('author', self.committer)
             if author is None:
-                return [self.committer]
+                return []
             return [author]
         else:
             return authors.split("\n")

=== modified file 'bzrlib/tests/test_revision.py'
--- bzrlib/tests/test_revision.py	2009-03-24 01:53:42 +0000
+++ bzrlib/tests/test_revision.py	2009-04-06 21:01:10 +0000
@@ -227,6 +227,14 @@
                 r.get_apparent_author)
         self.assertEqual('C', author)
 
+    def test_get_apparent_author_none(self):
+        r = revision.Revision('1')
+        r.committer = None
+        author = self.applyDeprecated(
+                symbol_versioning.deprecated_in((1, 13, 0)),
+                r.get_apparent_author)
+        self.assertEqual(None, author)
+
     def test_get_apparent_authors(self):
         r = revision.Revision('1')
         r.committer = 'A'
@@ -236,6 +244,10 @@
         r.properties['authors'] = 'C\nD'
         self.assertEqual(['C', 'D'], r.get_apparent_authors())
 
+    def test_get_apparent_authors_no_committer(self):
+        r = revision.Revision('1')
+        self.assertEqual([], r.get_apparent_authors())
+
 
 class TestRevisionBugs(TestCase):
     """Tests for getting the bugs that a revision is linked to."""

